@@ -161,7 +161,7 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         email: Option<String>,
         phone: Option<String>,
         undergraduate_school: Option<String>,
-        date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        date_of_birth: Option<NaiveDate>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
         specialism: Option<String>,
