@@ -176,6 +176,10 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub title: Option<models::StudentTitle>,
 
+    #[serde(rename = "progress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub progress: Option<models::VowProgress>,
+
     #[serde(rename = "firstName")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub first_name: Option<String>,
@@ -205,6 +209,10 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub phone: Option<String>,
 
+    #[serde(rename = "address")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub address: Option<String>,
+
     #[serde(rename = "undergraduateSchool")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub undergraduate_school: Option<String>,
@@ -229,6 +237,22 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub is_male: Option<bool>,
 
+    #[serde(rename = "nationalId")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub national_id: Option<String>,
+
+    #[serde(rename = "passport")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub passport: Option<String>,
+
+    #[serde(rename = "DateOfIssue")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub date_of_issue: Option<NaiveDate>,
+
+    #[serde(rename = "PlaceOfIssue")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub place_of_issue: Option<NaiveDate>,
+
 }
 
 impl StudentUpsert {
@@ -237,6 +261,7 @@ impl StudentUpsert {
             polity_id: None,
             saint_id_array: None,
             title: None,
+            progress: None,
             first_name: None,
             middle_name: None,
             last_name: None,
@@ -244,12 +269,17 @@ impl StudentUpsert {
             place_of_birth: None,
             email: None,
             phone: None,
+            address: None,
             undergraduate_school: None,
             nationality: Some("Vietnamese".to_string()),
             educational_stage: None,
             race: None,
             program_id: None,
             is_male: Some(true),
+            national_id: None,
+            passport: None,
+            date_of_issue: None,
+            place_of_issue: None,
         }
     }
 }
@@ -266,6 +296,8 @@ impl std::string::ToString for StudentUpsert {
 
         // Skipping title in query parameter serialization
 
+        // Skipping progress in query parameter serialization
+
 
         if let Some(ref first_name) = self.first_name {
             params.push("firstName".to_string());
@@ -305,6 +337,12 @@ impl std::string::ToString for StudentUpsert {
         }
 
 
+        if let Some(ref address) = self.address {
+            params.push("address".to_string());
+            params.push(address.to_string());
+        }
+
+
         if let Some(ref undergraduate_school) = self.undergraduate_school {
             params.push("undergraduateSchool".to_string());
             params.push(undergraduate_school.to_string());
@@ -332,6 +370,22 @@ impl std::string::ToString for StudentUpsert {
             params.push(is_male.to_string());
         }
 
+
+        if let Some(ref national_id) = self.national_id {
+            params.push("nationalId".to_string());
+            params.push(national_id.to_string());
+        }
+
+
+        if let Some(ref passport) = self.passport {
+            params.push("passport".to_string());
+            params.push(passport.to_string());
+        }
+
+        // Skipping DateOfIssue in query parameter serialization
+
+        // Skipping PlaceOfIssue in query parameter serialization
+
         params.join(",").to_string()
     }
 }
@@ -349,6 +403,7 @@ impl std::str::FromStr for StudentUpsert {
             pub polity_id: Vec<uuid::Uuid>,
             pub saint_id_array: Vec<Vec<uuid::Uuid>>,
             pub title: Vec<models::StudentTitle>,
+            pub progress: Vec<models::VowProgress>,
             pub first_name: Vec<String>,
             pub middle_name: Vec<String>,
             pub last_name: Vec<String>,
@@ -356,12 +411,17 @@ impl std::str::FromStr for StudentUpsert {
             pub place_of_birth: Vec<String>,
             pub email: Vec<String>,
             pub phone: Vec<String>,
+            pub address: Vec<String>,
             pub undergraduate_school: Vec<String>,
             pub nationality: Vec<String>,
             pub educational_stage: Vec<models::EducationalStage>,
             pub race: Vec<String>,
             pub program_id: Vec<uuid::Uuid>,
             pub is_male: Vec<bool>,
+            pub national_id: Vec<String>,
+            pub passport: Vec<String>,
+            pub date_of_issue: Vec<NaiveDate>,
+            pub place_of_issue: Vec<NaiveDate>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -381,6 +441,7 @@ impl std::str::FromStr for StudentUpsert {
                     "polityId" => intermediate_rep.polity_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "saintIdArray" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
                     "title" => intermediate_rep.title.push(<models::StudentTitle as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "progress" => intermediate_rep.progress.push(<models::VowProgress as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "firstName" => intermediate_rep.first_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "middleName" => intermediate_rep.middle_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "lastName" => intermediate_rep.last_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -388,12 +449,17 @@ impl std::str::FromStr for StudentUpsert {
                     "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "address" => intermediate_rep.address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "nationality" => intermediate_rep.nationality.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "EducationalStage" => intermediate_rep.educational_stage.push(<models::EducationalStage as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "race" => intermediate_rep.race.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "programId" => intermediate_rep.program_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "isMale" => intermediate_rep.is_male.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "nationalId" => intermediate_rep.national_id.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "passport" => intermediate_rep.passport.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "DateOfIssue" => intermediate_rep.date_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "PlaceOfIssue" => intermediate_rep.place_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing StudentUpsert".to_string())
                 }
             }
@@ -407,6 +473,7 @@ impl std::str::FromStr for StudentUpsert {
             polity_id: intermediate_rep.polity_id.into_iter().next(),
             saint_id_array: intermediate_rep.saint_id_array.into_iter().next(),
             title: intermediate_rep.title.into_iter().next(),
+            progress: intermediate_rep.progress.into_iter().next(),
             first_name: intermediate_rep.first_name.into_iter().next(),
             middle_name: intermediate_rep.middle_name.into_iter().next(),
             last_name: intermediate_rep.last_name.into_iter().next(),
@@ -414,12 +481,17 @@ impl std::str::FromStr for StudentUpsert {
             place_of_birth: intermediate_rep.place_of_birth.into_iter().next(),
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
+            address: intermediate_rep.address.into_iter().next(),
             undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
             nationality: intermediate_rep.nationality.into_iter().next(),
             educational_stage: intermediate_rep.educational_stage.into_iter().next(),
             race: intermediate_rep.race.into_iter().next(),
             program_id: intermediate_rep.program_id.into_iter().next(),
             is_male: intermediate_rep.is_male.into_iter().next(),
+            national_id: intermediate_rep.national_id.into_iter().next(),
+            passport: intermediate_rep.passport.into_iter().next(),
+            date_of_issue: intermediate_rep.date_of_issue.into_iter().next(),
+            place_of_issue: intermediate_rep.place_of_issue.into_iter().next(),
         })
     }
 }
@@ -873,3 +945,46 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
     }
 }
 
+
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum VowProgress {
+    #[serde(rename = "SOLEMN_VOW")]
+    SOLEMN_VOW,
+    #[serde(rename = "SIMPLE_VOW")]
+    SIMPLE_VOW,
+    #[serde(rename = "NOVICE")]
+    NOVICE,
+    #[serde(rename = "PREPARATION")]
+    PREPARATION,
+}
+
+impl std::fmt::Display for VowProgress {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            VowProgress::SOLEMN_VOW => write!(f, "{}", "SOLEMN_VOW"),
+            VowProgress::SIMPLE_VOW => write!(f, "{}", "SIMPLE_VOW"),
+            VowProgress::NOVICE => write!(f, "{}", "NOVICE"),
+            VowProgress::PREPARATION => write!(f, "{}", "PREPARATION"),
+        }
+    }
+}
+
+impl std::str::FromStr for VowProgress {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "SOLEMN_VOW" => std::result::Result::Ok(VowProgress::SOLEMN_VOW),
+            "SIMPLE_VOW" => std::result::Result::Ok(VowProgress::SIMPLE_VOW),
+            "NOVICE" => std::result::Result::Ok(VowProgress::NOVICE),
+            "PREPARATION" => std::result::Result::Ok(VowProgress::PREPARATION),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
