@@ -28,6 +28,7 @@ use crate::{Api,
      GetStudentByIdResponse,
      GetStudentsResponse
 };
+use chrono::NaiveDate;
 
 mod paths {
     use lazy_static::lazy_static;
@@ -615,7 +616,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                 let param_date_of_birth = match param_date_of_birth {
                     Some(param_date_of_birth) => {
                         let param_date_of_birth =
-                            <chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str
+                            <NaiveDate as std::str::FromStr>::from_str
                                 (&param_date_of_birth);
                         match param_date_of_birth {
                             Ok(param_date_of_birth) => Some(param_date_of_birth),
